@@ -6,19 +6,13 @@ class Resource(dict):
 
     @classmethod
     def get(cls, url, **options):
-        params = {}
-
-        for o in ['webhook_url', 'webhook_id', 'subscribe']:
-            if o in options:
-                params[o] = options[o]
-
+        params = options.get('params', {})
+        key = options.get('key', clearbit.key)
         endpoint = cls.endpoint + url
 
         if 'stream' in options:
             endpoint = endpoint.replace('.', '-stream.', 1)
 
-        key = options.get('key', clearbit.key)
-
         response = requests.get(endpoint, params=params, auth=(key, ''))
 
         if response.status_code == 200:
@@ -29,3 +23,16 @@ class Resource(dict):
             return None
         else:
             response.raise_for_status()
+
+    @classmethod
+    def post(cls, url, **options):
+        params = options.get('params', {})
+        key = options.get('key', clearbit.key)
+        endpoint = cls.endpoint + url
+
+        response = requests.post(endpoint, params=params, auth=(key, ''))
+
+        if response.status_code == 200:
+            return response
+        else:
+            response.raise_for_status()
